"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NotifierRegistry = void 0;
const LoggerFactory_1 = require("../utils/LoggerFactory");
const registryLogger = LoggerFactory_1.loggerFactory.createLogger({
    component: "NotifierRegistry",
});
class NotifierRegistry {
    static registry = new Map();
    static register(channelName, notifier) {
        if (this.registry.has(channelName)) {
            registryLogger.warn({ channel: channelName }, `Notifier is being re-registered. Overwriting previous instance.`);
        }
        else {
            registryLogger.info({ channel: channelName }, `Registering notifier.`);
        }
        this.registry.set(channelName, notifier);
    }
    static get(channelName) {
        const notifier = this.registry.get(channelName);
        if (!notifier) {
            registryLogger.error({ channel: channelName }, `Attempted to get notifier, but it was not registered.`);
            throw new Error(`Notifier for channel "${channelName}" not registered.`);
        }
        registryLogger.trace({ channel: channelName }, `Retrieved notifier.`);
        return notifier;
    }
    static unregister(channelName) {
        const deleted = this.registry.delete(channelName);
        if (deleted) {
            registryLogger.info({ channel: channelName }, `Unregistered notifier.`);
        }
        else {
            registryLogger.warn({ channel: channelName }, `Attempted to unregister notifier, but it was not found.`);
        }
    }
    static getRegisteredChannels() {
        return Array.from(this.registry.keys());
    }
    static clear() {
        registryLogger.warn("Clearing all registered notifiers.");
        this.registry.clear();
    }
}
exports.NotifierRegistry = NotifierRegistry;
//# sourceMappingURL=NotifierRegistry.js.map