"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.QueueManager = void 0;
const bullmq_1 = require("bullmq");
class QueueManager {
    static async enqueueJob(redisConnection, queueName, jobName, jobData, logger, jobOptions) {
        const enqueueLogger = logger.child({
            queue: queueName,
            jobName: jobName,
            campaignId: jobData.campaignId,
        });
        enqueueLogger.debug({ jobOptions }, "Attempting to enqueue job...");
        const queue = new bullmq_1.Queue(queueName, { connection: redisConnection });
        try {
            const job = await queue.add(jobName, jobData, jobOptions);
            enqueueLogger.info({ jobId: job.id, userCount: jobData.userIds?.length ?? 0 }, `Job enqueued successfully.`);
        }
        catch (error) {
            enqueueLogger.error({ err: error, jobOptions }, `Failed to enqueue job.`);
            throw error;
        }
        finally {
            enqueueLogger.trace("Enqueue operation finished.");
        }
    }
}
exports.QueueManager = QueueManager;
//# sourceMappingURL=QueueManager.js.map