"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loggerFactory = void 0;
const pino_1 = __importDefault(require("pino"));
const defaultOptions = {
    level: process.env.LOG_LEVEL || "info",
    formatters: { level: (label) => ({ level: label }) },
    timestamp: pino_1.default.stdTimeFunctions.isoTime,
    ...(process.env.NODE_ENV !== "production" && {
        transport: {
            target: "pino-pretty",
            options: {
                colorize: true,
                translateTime: "SYS:yyyy-mm-dd HH:MM:ss.l",
                ignore: "pid,hostname,component",
            },
        },
    }),
};
let rootLogger = (0, pino_1.default)(defaultOptions);
let currentLevel = defaultOptions.level;
exports.loggerFactory = {
    setLevel: (level) => {
        rootLogger.level = level;
        currentLevel = level;
        rootLogger.info({ newLevel: level }, `Root logger level set.`);
    },
    getLevel: () => {
        return currentLevel;
    },
    createLogger: (context) => {
        return rootLogger.child(context || {});
    },
};
//# sourceMappingURL=LoggerFactory.js.map