import { Redis, RedisOptions } from "ioredis";
import { Job, WorkerOptions as BullMQWorkerOptions } from "bullmq";
import { WorkerManager } from "../core/WorkerManager";
import { ServiceAccount } from "firebase-admin";
import { Logger as PinoLogger } from "pino";
export interface WorkerConfig {
    redisConnection: Redis | RedisOptions;
    queueName: string;
    concurrency?: number;
    trackingKey?: string;
    notifiers?: {
        telegram?: {
            botToken: string;
        };
        email?: {
            host: string;
            port: number;
            secure: boolean;
            auth: {
                user: string;
                pass: string;
            };
            from: string;
        };
        firebase?: ServiceAccount | string;
        web?: {
            publicKey: string;
            privateKey: string;
            contactEmail: string;
        };
    };
    onStart?: (job: Job, logger: PinoLogger) => Promise<void> | void;
    onComplete?: (job: Job, stats: Record<string, string>, logger: PinoLogger) => Promise<void> | void;
    resetStatsAfterCompletion?: boolean;
    onDrained?: (logger: PinoLogger) => Promise<void> | void;
    bullWorkerOptions?: Partial<BullMQWorkerOptions>;
}
export declare function startWorkerServer(config: WorkerConfig): WorkerManager;
